@@ -11,21 +11,21 @@ from .core.caching import CACHE as cache
 from .core.metadata import init_metadata
 from .core.settings import SETTINGS as settings
 from .datasets import Dataset, dataset, load_dataset, register_dataset
-from .helpers import Helper
 from .plotting import interactive_map, new_plot
 from .plotting import options as plotting_options
 from .plotting import plot_map
 from .readers import Reader
 from .sources import Source, load_source, register_source, source
+from .wrappers import Wrapper
 
-__version__ = "0.7.2"
+__version__ = "0.8.0"
 
 
 __all__ = [
     "cache",
     "dataset",
     "Dataset",
-    "Helper",
+    "Wrapper",
     "interactive_map",
     "load_dataset",
     "load_source",
