@@ -11,6 +11,8 @@ import getpass
 import logging
 import os
 import tempfile
+from contextlib import contextmanager
+from functools import wraps
 from typing import Callable
 
 import yaml
@@ -21,6 +23,8 @@ LOG = logging.getLogger(__name__)
 
 DOT_CLIMETLAB = os.path.expanduser("~/.climetlab")
 
+SETTINGS_STACK = []
+
 SETTINGS_AND_HELP = {
     "cache-directory": (
         os.path.join(tempfile.gettempdir(), "climetlab-%s" % (getpass.getuser(),)),
@@ -56,6 +60,10 @@ SETTINGS_AND_HELP = {
         5,
         """Number of threads used to download data.""",
     ),
+    "maximum-cache-size": (
+        "10GB",
+        """Maximum disk space used by the CliMetLab cache.""",
+    ),
 }
 
 DEFAULTS = {}
@@ -66,14 +74,36 @@ for k, v in SETTINGS_AND_HELP.items():
 NONE = object()
 
 
+@contextmanager
+def new_settings(s):
+    SETTINGS._stack.append(s)
+    try:
+        yield None
+    finally:
+        SETTINGS._stack.pop()
+        SETTINGS._notify()
+
+
+def forward(func):
+    @wraps(func)
+    def wrapped(self, *args, **kwargs):
+        if self._stack:
+            return func(self._stack[-1], *args, **kwargs)
+        return func(self, *args, **kwargs)
+
+    return wrapped
+
+
 class Settings:
-    def __init__(self, settings_yaml: str, defaults: dict):
+    def __init__(self, settings_yaml: str, defaults: dict, callbacks=[]):
         self._defaults = defaults
         self._settings = dict(**defaults)
-        self._callbacks = []
+        self._callbacks = [c for c in callbacks]
         self._settings_yaml = settings_yaml
         self._pytest = None
+        self._stack = []
 
+    @forward
     def get(self, name: str, default=NONE):
         """[summary]
 
@@ -93,6 +123,7 @@ class Settings:
 
         return self._settings.get(name, default)
 
+    @forward
     def set(self, name: str, *args, **kwargs):
         """[summary]
 
@@ -135,6 +166,7 @@ class Settings:
         self._settings[name] = value
         self._changed()
 
+    @forward
     def reset(self, name: str = None):
         """Reset setting(s) to default values.
 
@@ -153,6 +185,7 @@ class Settings:
                 self._settings[name] = DEFAULTS[name]
         self._changed()
 
+    @forward
     def _repr_html_(self):
         html = [css("table")]
         html.append("<table class='climetlab'>")
@@ -166,6 +199,9 @@ class Settings:
 
     def _changed(self):
         self._save()
+        self._notify()
+
+    def _notify(self):
         for cb in self._callbacks:
             cb()
 
@@ -174,6 +210,9 @@ class Settings:
 
     def _save(self):
 
+        if self._settings_yaml is None:
+            return
+
         try:
             with open(self._settings_yaml, "w") as f:
                 yaml.dump(self._settings, f, default_flow_style=False)
@@ -184,16 +223,40 @@ class Settings:
                 exc_info=True,
             )
 
+    def as_bytes(self, name):
+        value = str(self.get(name))
+        v = 0
+        while len(value) and str.isdigit(value[0]):
+            v *= 10
+            v += int(value[0])
+            value = value[1:]
+        # bytes = {"%": 0.01}
+        bytes = {}
+        n = 1
+        for u in "KMGTP":
+            n *= 1024
+            bytes[u] = n
+        if len(value):
+            v *= bytes[value[0].upper()]
+        return v
+
+    @forward
+    def temporary(self, name=None, *args, **kwargs):
+        tmp = Settings(None, self._settings, self._callbacks)
+        if name is not None:
+            tmp.set(name, *args, **kwargs)
+        return new_settings(tmp)
+
+
+save = False
+settings_yaml = os.path.expanduser("~/.climetlab/settings.yaml")
 
 try:
     if not os.path.exists(DOT_CLIMETLAB):
         os.mkdir(DOT_CLIMETLAB, 0o700)
-
-    settings_yaml = os.path.expanduser("~/.climetlab/settings.yaml")
     if not os.path.exists(settings_yaml):
         with open(settings_yaml, "w") as f:
             yaml.dump(DEFAULTS, f, default_flow_style=False)
-
 except Exception:
     LOG.error(
         "Cannot create CliMetLab settings directory, using defaults (%s)",
@@ -201,13 +264,15 @@ except Exception:
         exc_info=True,
     )
 
-
 settings = dict(**DEFAULTS)
 try:
     with open(settings_yaml) as f:
         s = yaml.load(f, Loader=yaml.SafeLoader)
         settings.update(s)
 
+    if s != settings:
+        save = True
+
 except Exception:
     LOG.error(
         "Cannot load CliMetLab settings (%s), reverting to defaults",
@@ -216,3 +281,5 @@ except Exception:
     )
 
 SETTINGS = Settings(settings_yaml, settings)
+if save:
+    SETTINGS._save()
