@@ -12,7 +12,12 @@ import os
 import shutil
 
 import requests
-from tqdm.auto import tqdm
+
+try:
+    import ipywidgets  # noqa
+    from tqdm.auto import tqdm
+except ImportError:
+    from tqdm import tqdm
 
 from .base import FileSource
 
@@ -20,10 +25,12 @@ LOG = logging.getLogger(__name__)
 
 
 class Url(FileSource):
-    def __init__(self, url, unpack=None, **kwargs):
+    def __init__(self, url, unpack=None, verify=True, **kwargs):
 
         super().__init__(**kwargs)
 
+        self.verify = verify
+
         base, ext = os.path.splitext(url)
         _, tar = os.path.splitext(base)
         if tar == ".tar":
@@ -32,33 +39,45 @@ class Url(FileSource):
         if unpack is None:
             unpack = ext in (".tar", ".tar.gz")
 
-        if unpack:
-            self.path = self.cache_file(url, extension=".d")
-            if not os.path.exists(self.path):
-                archive = self.path + ext
-                self.download(url, archive)
-                self.unpack(archive, self.path)
-                os.unlink(archive)
-        else:
-            _, ext = os.path.splitext(url)
-            self.path = self.cache_file(url, extension=ext)
-            if not os.path.exists(self.path):
-                self.download(url, self.path)
+        def download(target, url):
+            return self._download(url, target)
 
-    def download(self, url, target):
+        def download_and_unpack(target, url):
+            archive = target + ext
+            download(archive, url)
+            LOG.info("Unpacking...")
+            shutil.unpack_archive(archive, target)
+            LOG.info("Done.")
+            os.unlink(archive)
+
+        if unpack:
+            self.path = self.cache_file(
+                download_and_unpack,
+                url,
+                extension=".d",
+            )
+        else:
+            self.path = self.cache_file(
+                download,
+                url,
+                extension=ext,
+            )
+
+    def _download(self, url, target):
 
         if os.path.exists(target):
             return
 
-        LOG.info("Downloading %s", url)
         download = target + ".download"
-        r = requests.head(url)
+        LOG.info("Downloading %s", url)
+
+        r = requests.head(url, verify=self.verify)
         r.raise_for_status()
         try:
             size = int(r.headers["content-length"])
         except Exception:
             size = None
-        r = requests.get(url, stream=True)
+        r = requests.get(url, stream=True, verify=self.verify)
         r.raise_for_status()
         mode = "wb"
         with tqdm(
@@ -82,17 +101,5 @@ class Url(FileSource):
 
         os.rename(download, target)
 
-    def unpack(self, archive, directory):
-        if os.path.exists(directory):
-            return
-        LOG.info("Unpacking...")
-        target = directory + ".tmp"
-        if not os.path.exists(target):
-            os.mkdir(target)
-
-        shutil.unpack_archive(archive, target)
-        os.rename(target, directory)
-        LOG.info("Done.")
-
 
 source = Url
