@@ -13,7 +13,13 @@ import os
 
 import pytest
 
-IGNORE = ["conf.py", "xml2rst.py", "actions.py", "generate-examples-maps.py"]
+IGNORE = [
+    "conf.py",
+    "xml2rst.py",
+    "actions.py",
+    "generate-examples-maps.py",
+    "settings-2-set.py",
+]
 EXAMPLES = os.path.join(os.path.dirname(os.path.dirname(__file__)), "docs")
 
 
