@@ -33,3 +33,10 @@ def test_numpy_xarray():
     s = cml.load_source("file", "docs/examples/test.nc")
     x = s.to_xarray()
     cml.plot_map(x.msl.values, metadata=x.msl)
+
+
+if __name__ == "__main__":
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
