@@ -10,11 +10,10 @@
 #
 
 import os
-import sys
 
 import pytest
 
-from climetlab import load_source, source
+from climetlab import load_source
 
 
 def test_file_source_grib():
@@ -27,12 +26,13 @@ def test_file_source_netcdf():
     assert len(s) == 2
 
 
-@pytest.mark.skipif(
-    True or sys.version_info < (3, 7), reason="Version 3.7 or greater needed"
-)
-def test_file_source_shortcut():
-    s = source.file("docs/examples/test.grib")
-    assert len(s) == 2
+# obsolete
+# @pytest.mark.skipif(
+#     True or sys.version_info < (3, 7), reason="Version 3.7 or greater needed"
+# )
+# def test_file_source_shortcut():
+#     s = source.file("docs/examples/test.grib")
+#     assert len(s) == 2
 
 
 def test_file_source_mars():
@@ -86,17 +86,17 @@ def test_file_source_cds_grib():
 #    assert len(s) == 2
 
 
-def test_ulr_source_1():
+def test_url_source_1():
     load_source("url", "http://download.ecmwf.int/test-data/metview/gallery/temp.bufr")
 
 
-def test_ulr_source_2():
+def test_url_source_2():
     load_source(
         "url", "https://github.com/ecmwf/climetlab/raw/master/docs/examples/test.grib"
     )
 
 
-def test_ulr_source_3():
+def test_url_source_3():
     load_source(
         "url", "https://github.com/ecmwf/climetlab/raw/master/docs/examples/test.nc"
     )
